#ifndef NT2_INCLUDE_FUNCTIONS_EXPONENTBITS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXPONENTBITS_HPP_INCLUDED

#include <nt2/ieee/include/functions/exponentbits.hpp>

#endif
